﻿using ThinkGeo.MapSuite.Core;

namespace OledbPointFeatureSource
{
    // The FeatureLayer is a wrapper to the FeatureSource and provides all of the drawing specific
    // methods such as the ZoomLevels and Styles.  As you can see it is just a simple wrapper and the
    // real work is already done for you in the FeatureLayer base class.
    class OledbPointFeatureLayer: FeatureLayer
    {
        OledbPointFeatureSource oledbPointFeatureSource;

        // It is important for compatability that you always have a default constructor that
        // takes no parameters.  This constructor will just chain to the more complex one.
        public OledbPointFeatureLayer()
            : this(string.Empty, string.Empty, string.Empty, string.Empty, string.Empty)
        { }

        // We have provided another constructor that has all of the parameters we need for the FeatureLayer
        // to work.
        public OledbPointFeatureLayer(string tableName, string idColumnName, string xColumnName, string yColumnName, string connectionString)
            : base()
        {
            // Here is where we create our FeatureSource and set the internal property on the FeatureLayer
            oledbPointFeatureSource = new OledbPointFeatureSource(tableName, idColumnName, xColumnName, yColumnName, connectionString);
            this.FeatureSource = oledbPointFeatureSource;           
        }

        // The next dozen lines are all of the properties we need.  It is good form to always match
        // the parameters in your constructors with properties of the exact same name.
        public string TableName
        {
            get { return oledbPointFeatureSource.TableName; }
            set { oledbPointFeatureSource.TableName = value; }
        }

        public string ConnectionString
        {
            get { return oledbPointFeatureSource.ConnectionString; }
            set { oledbPointFeatureSource.ConnectionString = value; }
        }

        public string XColumnName
        {
            get { return oledbPointFeatureSource.XColumnName; }
            set { oledbPointFeatureSource.XColumnName = value; }
        }

        public string YColumnName
        {
            get { return oledbPointFeatureSource.YColumnName; }
            set { oledbPointFeatureSource.YColumnName = value; }
        }

        public string IdColumnName
        {
            get { return oledbPointFeatureSource.IdColumnName; }
            set { oledbPointFeatureSource.IdColumnName = value; }
        }
    }
}
