﻿using System;
using System.Drawing;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace OledbPointFeatureSource
{
    public partial class TestForm : Form
    {
        private MapEngine mapEngine = new MapEngine();
        private Bitmap bitmap = null;

        public TestForm()
        {
            InitializeComponent();
        }

        private void TestForm_Load(object sender, EventArgs e)
        {
            // Set the full extent and the background color
            mapEngine.CurrentExtent = ExtentHelper.GetDrawingExtent(new RectangleShape(-180.0, 83.0, 180.0, -90.0), Map.Width, Map.Height);
            mapEngine.BackgroundFillBrush = new GeoSolidBrush(GeoColor.GeographicColors.DeepOcean);

            // Setup the cities layer - OledbPointFeatureSource
            string connectionString = @"Provider=Microsoft.Jet.OLEDB.4.0;Data Source=..\..\..\Dependencies\Cities.mdb;User Id=admin;Password=;";
            OledbPointFeatureLayer citiesLayer = new OledbPointFeatureLayer("Cities", "ID", "X", "Y", connectionString);
            citiesLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;
            citiesLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.City1("CityName"); ;
            citiesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Setup the countries layer
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\..\Dependencies\Countries02.shp",ShapeFileReadWriteMode.ReadOnly);
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Setup the ThinkGeo layer - MinimumFeatureSource
            MinimumFeatureLayer thinkGeoLayer = new MinimumFeatureLayer();
            thinkGeoLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.GetSimpleStarStyle(GeoColor.StandardColors.Red, 10);
            thinkGeoLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;            

            // Add the new layers to the MapEngine
            mapEngine.StaticLayers.Add("WorldLayer", worldLayer);
            mapEngine.StaticLayers.Add("CitiesLayer", citiesLayer);
            mapEngine.StaticLayers.Add("ThinkGeoLayer", thinkGeoLayer);

            DrawImage();
        }

        private void btnGetCount_Click(object sender, EventArgs e)
        {
            FeatureLayer citiesLayer = (FeatureLayer)mapEngine.StaticLayers["CitiesLayer"];
            citiesLayer.Open();
            MessageBox.Show("Number of cities: " + citiesLayer.FeatureSource.GetCount(), "Get Count");
            citiesLayer.Close();
        }

        private void DrawImage()
        {
            if (bitmap != null) { bitmap.Dispose(); }
            bitmap = new Bitmap(Map.Width, Map.Height);
            mapEngine.OpenAllLayers();
            mapEngine.DrawStaticLayers(bitmap, GeographyUnit.DecimalDegree);
            mapEngine.CloseAllLayers();

            Map.Image = bitmap;
        }

        private void ToolBar_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
        {
            switch (e.Button.Tag.ToString())
            {
                case "Zoom In":
                    mapEngine.CurrentExtent.ScaleDown(50);                    
                    break;
                case "Zoom Out":
                    mapEngine.CurrentExtent.ScaleUp(50);                    
                    break;
                case "Full Extent":
                    mapEngine.CurrentExtent = ExtentHelper.GetDrawingExtent(new RectangleShape(-180.0, 83.0, 180.0, -90.0), Map.Width, Map.Height);                    
                    break;
                case "Pan Left":
                    mapEngine.CurrentExtent = ExtentHelper.Pan(mapEngine.CurrentExtent, PanDirection.Left, 40);                    
                    break;
                case "Pan Right":
                    mapEngine.CurrentExtent = ExtentHelper.Pan(mapEngine.CurrentExtent, PanDirection.Right, 40);
                    break;
                case "Pan Up":
                    mapEngine.CurrentExtent = ExtentHelper.Pan(mapEngine.CurrentExtent, PanDirection.Up, 20);
                    break;
                case "Pan Down":
                    mapEngine.CurrentExtent = ExtentHelper.Pan(mapEngine.CurrentExtent, PanDirection.Down, 20);
                    break;
                default:
                    break;
            }
            DrawImage();
        }
    
        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
